@@ -472,10 +472,21 @@ class StaticScraper:
         time.sleep(self.info.timesleep)
         
         return scraped
+    
+    def __show_progress(self, page = None, progress = None, pages = None, finish = False):
         
+        
+        if (finish):
+            
+            sys.stdout.flush()
+        
+        else:
+            
+            sys.stdout.write(f"\r\tScraping page {page} ({progress}/{pages})")
+    
     def scrape(self, start = 1, pages = 1):
         
-        start = True
+        _start = True
         
         print(f"Scraping {self.info.info['f_site']}")
         
@@ -483,23 +494,25 @@ class StaticScraper:
             
             progress = page - start + 1
             
-            print(f"\tScraping page {page} ({progress}/{pages})")
+            self.__show_progress(page, progress, pages)
             
             self.info.add_data(self.__scrape_webpage(page))
             
             if (self.info.buffer_exceeded()):
                 
-                self.info.save_data(start)
+                self.info.save_data(_start)
                 
                 self.info.empty_data()
                 
-                start = False
+                _start = False
             
-            print(f"\t\tScraped page {page} ({progress}/{pages})\n")
+            self.__show_progress(finish = True)
+            
+        print("")
             
         if (len(self.info.data)):
             
-            self.info.save_data(start)
+            self.info.save_data(_start)
             
             self.info.empty_data()
 """
@@ -519,7 +532,7 @@ attrList = [
 info = SSInfo(website, pageformat, itemformat, attrList)
 data = SSData(info, timesleep = 2)
 scraper = StaticScraper(data)
-scraper.scrape(start = 1, pages = 5)
+scraper.scrape(start = 1, pages = 20)
 """
 """
 SSSave.help()
